==> RCLabels_0.0.4.tar.gz: RCLabels/R/data.R <==
#' Arrow notation
#'
#' A description of arrow notation.
#'
#' @format A vector of notational symbols that provides an arrow separator ("a -> b")
#'         between prefix and suffix.
#' @examples
#' arrow_notation
"arrow_notation"


#' Parenthetical notation
#'
#' A description of parenthetical notation.
#'
#' @format A vector of notational symbols that provides a parenthetical ("a (b)") notation.
#' @examples
#' paren_notation
"paren_notation"


#' Bracket notation
#'
#' A description of bracket notation.
#'
#' @format A vector of notational symbols that provides bracket ("a \[b\]") notation.
#' @examples
#' bracket_notation
"bracket_notation"


#' From notation
#'
#' A description of from notation.
#'
#' @format A vector of notational symbols that provides from ("a \[from b\]") notation.
#' @examples
#' from_notation
"from_notation"


#' Of notation
#'
#' A description of of notation.
#'
#' @format A vector of notational symbols that provides of ("a \[of b\]") notation.
#' @examples
#' of_notation
"of_notation"


#' To notation
#'
#' A description of to notation.
#'
#' @format A vector of notational symbols that provides to ("a \[to b\]") notation.
#' @examples
#' from_notation
"to_notation"


#' Bracket arrow notation
#'
#' A description of bracket arrow notation.
#'
#' @format A vector of notational symbols that provides bracket arrow ("a \[-> b\]") notation.
#' @examples
#' bracket_arrow_notation
"bracket_arrow_notation"



#' Prepositions
#'
#' Prepositions used in row and column labels.
#'
#' @format A list of prepositions used in row and column labels.
#' @examples
#' prepositions
"prepositions"

==> RCLabels_0.1.0.tar.gz: RCLabels/R/data.R <==
#' Arrow notation
#'
#' A description of arrow notation.
#'
#' @format A vector of notational symbols that provides an arrow separator ("a -> b")
#'         between prefix and suffix.
#' @examples
#' arrow_notation
"arrow_notation"


#' Parenthetical notation
#'
#' A description of parenthetical notation.
#'
#' @format A vector of notational symbols that provides a parenthetical ("a (b)") notation.
#' @examples
#' paren_notation
"paren_notation"


#' Bracket notation
#'
#' A description of bracket notation.
#'
#' @format A vector of notational symbols that provides bracket ("a \[b\]") notation.
#' @examples
#' bracket_notation
"bracket_notation"


#' From notation
#'
#' A description of from notation.
#'
#' @format A vector of notational symbols that provides from ("a \[from b\]") notation.
#' @examples
#' from_notation
"from_notation"


#' Of notation
#'
#' A description of of notation.
#'
#' @format A vector of notational symbols that provides of ("a \[of b\]") notation.
#' @examples
#' of_notation
"of_notation"


#' To notation
#'
#' A description of to notation.
#'
#' @format A vector of notational symbols that provides to ("a \[to b\]") notation.
#' @examples
#' from_notation
"to_notation"


#' Bracket arrow notation
#'
#' A description of bracket arrow notation.
#'
#' @format A vector of notational symbols that provides bracket arrow ("a \[-> b\]") notation.
#' @examples
#' bracket_arrow_notation
"bracket_arrow_notation"



#' Prepositions
#'
#' Prepositions used in row and column labels.
#'
#' @format A vector of prepositions used in row and column labels.
#' @examples
#' prepositions
"prepositions"
